@@ -1,7 +1,7 @@
 export_projet_qgis_ronds_classes <-
 function(liste_fonds,chemin_fonds,nom_projet,titre,titre2,sourc,titre_leg_classes,table_classe,variable_a_representer,annee)
   {
-    chemin_fonds <- paste0(chemin_fonds,"/")
+    chemin_fonds <- paste0(chemin_fonds,"/layers/")
     
     fond_maille <- read_sf(paste0(chemin_fonds,"fond_maille.shp"))
     
@@ -71,6 +71,7 @@ function(liste_fonds,chemin_fonds,nom_projet,titre,titre2,sourc,titre_leg_classe
       #param idcouche, chemincouche, nomcouche
       nomcouche=l[i]
       chemincouche=paste0(chemin_fonds,nomcouche,".shp")
+      chemincoucherelatif=paste0("./layers/",nomcouche,".shp")
       
       BLOCCATEGORIES=data.frame()      
       #cas ou le fond selectionne est la carte ou la legende
@@ -80,59 +81,39 @@ function(liste_fonds,chemin_fonds,nom_projet,titre,titre2,sourc,titre_leg_classe
         geometrie=attr(analyse_classes$geometry[[1]],"class")[2]
         projcouche=st_crs(analyse_classes$geometry)$proj4string
         
-        #preparation des param du BLOCSYMBOL
-        if(str_sub(l[i][length(l[i])],start=-9)=="leg_carte")
+        attr="attr='classe'"
+        typeanalyse="categorizedSymbol"
+        BLOCSYMBOLS=data.frame()
+        BLOCCATEGORIES=data.frame(V1="                <categories>")
+        BLOCVECTOR=data.frame()
+        
+        for(j in 1:dim(table_classe)[1])
         {
-          attr=""
-          name="0"
-          typeanalyse="singleSymbol"
-          
+          #creer le bloc categories
+          symbol=name=as.character(j)
+          value=table_classe[j,1]
+          label=table_classe[j,2]
+          #value=label=table_classe[j,2]
+          temp=modif_bloccategories(symbol,value,label)
+          BLOCCATEGORIES=rbind(BLOCCATEGORIES,temp)
+          #creer autant de bloc symbols que de classes avec le bon canevas symbols
           stylebordure="solid"
           epaisseurbordure=0.26
-          couleurbordure="0,0,0"
-          couleurfond="transparent"
-          
+          couleurbordure=unique(analyse_classes$COL_BOR)
+          couleurfond=as.character(table_classe[j,3])
           remplissagefond="solid"
-          BLOCSYMBOLS=modif_blocsymbolsPolygon(couleurfond,couleurbordure,remplissagefond,stylebordure,epaisseurbordure,name)
-          
-          toto=modif_blocprojectlayers(geometrie,idcouche,chemincouche,nomcouche,projcouche,attr,typeanalyse)
-          toto=rbind(data.frame(V1=toto[1:13,]),BLOCCATEGORIES,data.frame(V1=toto[15,]),BLOCSYMBOLS,data.frame(V1=toto[17:23,]))
-          BLOCPROJECT=rbind(BLOCPROJECT,toto)
-        }else
-        {
-          attr="attr='classe'"
-          typeanalyse="categorizedSymbol"
-          BLOCSYMBOLS=data.frame()
-          BLOCCATEGORIES=data.frame(V1="                <categories>")
-          BLOCVECTOR=data.frame()
-          
-          for(j in 1:dim(table_classe)[1])
-          {
-            #creer le bloc categories
-            symbol=name=as.character(j)
-            value=table_classe[j,1]
-            label=table_classe[j,2]
-            #value=label=table_classe[j,2]
-            temp=modif_bloccategories(symbol,value,label)
-            BLOCCATEGORIES=rbind(BLOCCATEGORIES,temp)
-            #creer autant de bloc symbols que de classes avec le bon canevas symbols
-            stylebordure="solid"
-            epaisseurbordure=0.26
-            couleurbordure=unique(analyse_classes$COL_BOR)
-            couleurfond=as.character(table_classe[j,3])
-            remplissagefond="solid"
-            temp=modif_blocsymbolsPolygon(couleurfond,couleurbordure,remplissagefond,stylebordure,epaisseurbordure,name)
-            BLOCSYMBOLS=rbind(BLOCSYMBOLS,temp)  
-            #MEP
-            blocvector=modif_blocvectorClassification(table_classe[j,2])
-            blocvector=data.frame(V1=c(blocvector[1:2,],temp[,1],blocvector[4:5,]))
-            BLOCVECTOR=rbind(BLOCVECTOR,blocvector)  
-          }
-          BLOCCATEGORIES=rbind(BLOCCATEGORIES,data.frame(V1="                </categories>"))
-          bloclayeritem=data.frame(V1=c(bloclayeritem[1,],BLOCVECTOR[,1],bloclayeritem[3,]))
-          BLOCLAYERITEM=rbind(BLOCLAYERITEM,bloclayeritem)
+          temp=modif_blocsymbolsPolygon(couleurfond,couleurbordure,remplissagefond,stylebordure,epaisseurbordure,name)
+          BLOCSYMBOLS=rbind(BLOCSYMBOLS,temp)  
+          #MEP
+          blocvector=modif_blocvectorClassification(table_classe[j,2])
+          blocvector=data.frame(V1=c(blocvector[1:2,],temp[,1],blocvector[4:5,]))
+          BLOCVECTOR=rbind(BLOCVECTOR,blocvector)  
         }
-        toto=modif_blocprojectlayers(geometrie,idcouche,chemincouche,nomcouche,projcouche,attr,typeanalyse)
+        BLOCCATEGORIES=rbind(BLOCCATEGORIES,data.frame(V1="                </categories>"))
+        bloclayeritem=data.frame(V1=c(bloclayeritem[1,],BLOCVECTOR[,1],bloclayeritem[3,]))
+        BLOCLAYERITEM=rbind(BLOCLAYERITEM,bloclayeritem)
+        
+        toto=modif_blocprojectlayers(geometrie,idcouche,chemincoucherelatif,nomcouche,projcouche,attr,typeanalyse)
         toto=rbind(data.frame(V1=toto[1:13,]),BLOCCATEGORIES,data.frame(V1=toto[15,]),BLOCSYMBOLS,data.frame(V1=toto[17:23,]))
         BLOCPROJECT=rbind(BLOCPROJECT,toto)
       }else
@@ -160,7 +141,7 @@ function(liste_fonds,chemin_fonds,nom_projet,titre,titre2,sourc,titre_leg_classe
         }
         
         stylebordure="solid"
-        if (l[i] %in% c("fond_maille","fond_maille_elargi","fond_lignes_leg","fond_departement","fond_pays","fond_etranger","fond_territoire"))
+        if (l[i] %in% c("fond_maille","fond_maille_elargi","fond_departement","fond_pays","fond_etranger","fond_territoire"))
         {
           epaisseurbordure=0.26
         }else
@@ -197,16 +178,27 @@ function(liste_fonds,chemin_fonds,nom_projet,titre,titre2,sourc,titre_leg_classe
         bloclayeritem=data.frame(V1=c(bloclayeritem[1,],blocvector[,1],bloclayeritem[3,]))
         BLOCLAYERITEM=rbind(BLOCLAYERITEM,bloclayeritem)
         
-        toto=modif_blocprojectlayers(geometrie,idcouche,chemincouche,nomcouche,projcouche,attr,typeanalyse)
-        toto=rbind(data.frame(V1=toto[1:13,]),BLOCCATEGORIES,data.frame(V1=toto[15,]),BLOCSYMBOLS,data.frame(V1=toto[17:23,]))
+        if (l[i]=="fond_ronds_leg")
+        {
+          BLOCSYMBOLSGENERATOR <- balises_qgis()[[11]]
+          BLOCLABELING <- balises_qgis()[[12]]
+        }else
+        {
+          BLOCSYMBOLSGENERATOR <- data.frame()
+          BLOCLABELING <- data.frame()
+        }
+        
+        toto=modif_blocprojectlayers(geometrie,idcouche,chemincoucherelatif,nomcouche,projcouche,attr,typeanalyse)
+        toto=rbind(data.frame(V1=toto[1:13,]),BLOCCATEGORIES,data.frame(V1=toto[15,]),data.frame(V1=BLOCSYMBOLS[1:11,]),BLOCSYMBOLSGENERATOR,data.frame(V1=BLOCSYMBOLS[12,]),data.frame(V1=toto[17:20,]),BLOCLABELING,data.frame(V1=toto[21:23,]))
         BLOCPROJECT=rbind(BLOCPROJECT,toto)
       }
     }
     projproj=projcouche
     qgs1=modif_canevas(xmin,xmax,ymin,ymax,projproj,length(l))
     #etape finale
+    blocproperties <- balises_qgis()[[13]]
     BLOCCOMPOSER=data.frame(V1=c(BLOCCOMPOSER[1:43,],BLOCLAYERITEM[,1],BLOCCOMPOSER[45:94,]))
-    canevas_final=data.frame(V1=c(qgs1[1:19,],BLOCLEG[,1],qgs1[21,],BLOCCOMPOSER[,1],qgs1[23,],BLOCPROJECT[,1],qgs1[25:26,]))
+    canevas_final=data.frame(V1=c(qgs1[1:19,],BLOCLEG[,1],qgs1[21,],BLOCCOMPOSER[,1],qgs1[23,],BLOCPROJECT[,1],qgs1[25,],blocproperties[,1],qgs1[26,]))
     colnames(canevas_final)=NULL
-    write.csv(canevas_final,paste0(chemin_fonds,nom_projet,".qgs"),row.names = F, quote = F, fileEncoding = "UTF-8")
+    write.csv(canevas_final,paste0(substr(chemin_fonds,1,nchar(chemin_fonds)-7),nom_projet,".qgs"),row.names = F, quote = F, fileEncoding = "UTF-8")
   }
