@@ -9,21 +9,22 @@ function(map,cheminDossier,nomFichier,titre1="",titre2="",source="")
 
     if(is.null(list_fonds)) stop(simpleError("La legende des ronds ou des classes n'a pas ete creee. Veuillez svp utiliser les fonctions add_legende_ronds(map) et add_legende_classes(map) pour ajouter une legende a votre carte."))
 
+    dir.create(paste0(rep_sortie,"/layers"),showWarnings = F)
+    
     for(i in 1:length(list_fonds[[1]]))
     {
-      suppressWarnings(st_write(list_fonds[[1]][[i]], paste0(rep_sortie,"/",list_fonds[[2]][[i]],".shp"), delete_dsn = TRUE, quiet = TRUE))
+      suppressWarnings(st_write(list_fonds[[1]][[i]], paste0(rep_sortie,"/layers/",list_fonds[[2]][[i]],".shp"), delete_dsn = TRUE, quiet = TRUE))
     }
 
     annee <- format(Sys.time(), format = "%Y")
 
     l <- c()
+    if(any(list_fonds[[2]] %in% "fond_ronds_leg")) l <- c(l,"fond_ronds_leg")
     if(any(list_fonds[[2]] %in% "fond_ronds_classes_carte")) l <- c(l,"fond_ronds_classes_carte")
     if(any(list_fonds[[2]] %in% "fond_ronds_classes_elargi_carte")) l <- c(l,"fond_ronds_classes_elargi_carte")
     if(any(list_fonds[[2]] %in% "fond_maille")) l <- c(l,"fond_maille")
     if(any(list_fonds[[2]] %in% "fond_maille_elargi")) l <- c(l,"fond_maille_elargi")
-    if(any(list_fonds[[2]] %in% "fond_lignes_leg")) l <- c(l,"fond_lignes_leg")
-    if(any(list_fonds[[2]] %in% "fond_ronds_leg_carte")) l <- c(l,"fond_ronds_leg_carte")
-
+    
     if(any(list_fonds[[2]] %in% "fond_france")) l <- c(l,"fond_france")
     if(any(list_fonds[[2]] %in% "fond_pays"))l <- c(l,"fond_pays")
     if(any(list_fonds[[2]] %in% "fond_etranger"))l <- c(l,"fond_etranger")
