@@ -24,13 +24,13 @@ function(map)
       {
         if(map$x$calls[[i]]$args[[5]] %in% c("carte_ronds","carte_ronds_elargi")) idx_carte_ronds <- c(idx_carte_ronds,i)
       }
-      if(map$x$calls[[i]]$method %in% "addRectangles")
+      if(map$x$calls[[i]]$method %in% "addPolygons")
       {
-        if(map$x$calls[[i]]$args[[6]]=="legende_classes") idx_legende <- c(idx_legende,i)
+        if(map$x$calls[[i]]$args[[3]]=="legende_classes_rectangle") idx_legende <- c(idx_legende,i)
       }
-      if(map$x$calls[[i]]$method %in% "addCircles")
+      if(map$x$calls[[i]]$method %in% "addPolygons")
       {
-        if(map$x$calls[[i]]$args[[5]]=="legende_ronds") idx_legende_ronds <- c(idx_legende_ronds,i)
+        if(map$x$calls[[i]]$args[[3]]=="legende_ronds") idx_legende_ronds <- c(idx_legende_ronds,i)
       }
       if(!is.null(idx_legende)) # la legende de classes existe
       {
@@ -45,6 +45,10 @@ function(map)
       }
       if(!is.null(idx_legende_ronds)) # la legende de ronds existe
       {
+        if(map$x$calls[[i]]$method %in% "addCircles")
+        {
+          if(map$x$calls[[i]]$args[[5]]=="legende_ronds") idx_legende_ronds <- c(idx_legende_ronds,i)
+        }
         if(map$x$calls[[i]]$method %in% "addPolylines")
         {
           if(map$x$calls[[i]]$args[[3]]=="legende_ronds") idx_legende_ronds <- c(idx_legende_ronds,i)
@@ -161,7 +165,10 @@ function(map)
             }
             if(map$x$calls[[idx_legende[i]]]$method %in% "addPolygons")
             {
-              palette <- c(palette,map$x$calls[[idx_legende[i]]]$args[[4]]$fillColor)
+              if(map$x$calls[[idx_legende[i]]]$args[[3]] != "legende_classes_rectangle")
+              {
+                palette <- c(palette,map$x$calls[[idx_legende[i]]]$args[4][[1]]$fillColor)
+              }
             }
           }
         }
@@ -181,7 +188,7 @@ function(map)
             dd <- st_buffer(cc, map$x$calls[[idx_legende_ronds[i]]]$args[[3]])
 
             val <- c(map$x$calls[[idx_legende_ronds[i]]]$args[[7]][1],map$x$calls[[idx_legende_ronds[i]]]$args[[7]][2])
-            ronds_pl_leg <- cbind(VAL=val,dd)
+            ronds_pl_leg <- cbind(ETI_VAL=val,dd)
 
             list_fonds[[l]] <- ronds_pl_leg
             nom_fonds <- c(nom_fonds,map$x$calls[[idx_legende_ronds[i]]]$args[[4]]$nom_fond)
@@ -199,18 +206,6 @@ function(map)
             pts2_grand_pl <- c(x2_grand_pl,y2_grand_pl)
             ligne_grand_pl <- rbind(pts1_grand_pl,pts2_grand_pl)
 
-            x1_petit_pl <- x1_grand_pl
-            y1_petit_pl <- max(st_coordinates(ronds_pl_leg)[which(st_coordinates(ronds_pl_leg)[,4]==2),"Y"])
-            pts1_petit_pl <- c(x1_petit_pl,y1_petit_pl)
-            x2_petit_pl <- x2_grand_pl
-            y2_petit_pl <- max(st_coordinates(ronds_pl_leg)[which(st_coordinates(ronds_pl_leg)[,4]==2),"Y"])
-            pts2_petit_pl <- c(x2_petit_pl,y2_petit_pl)
-            ligne_petit_pl <- rbind(pts1_petit_pl,pts2_petit_pl)
-
-            lignes_pl <- st_sf(st_geometry(st_multilinestring(list(ligne_grand_pl,ligne_petit_pl))))
-            lignes_pl <- st_set_crs(lignes_pl,as.numeric(map$x$calls[[idx_legende_ronds[i]]]$args[[2]]$code_epsg))
-
-            list_fonds[[l]] <- lignes_pl
             nom_fonds <- c(nom_fonds,map$x$calls[[idx_legende_ronds[i]]]$args[[2]]$nom_fond)
             l <- l+1
           }
