@@ -38,7 +38,7 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
     if(any(class(titreCarte)!="character")) msg_error29 <- "Le titre de la carte doit etre de type caractere / "
     if(any(class(sourceCarte)!="character")) msg_error30 <- "La source de la carte doit etre de type caractere / "
     if(!is.null(etiquettes)) if(!any(class(etiquettes) %in% "character" | class(etiquettes) %in% "data.frame")) msg_error31 <- "La table des etiquettes peut etre soit un vecteur caractere soit un data.frame (voir aide) / "
-    if(any(class(stylePalette)!="character")) msg_error32 <- "Le style de la palette doit etre de type caractere ('InseeFlash', 'InseeAnalyse', 'InseeDossier', 'InseePremiere' ou 'defaut') / "
+    if(!is.null(stylePalette)) if(any(class(stylePalette)!="character")) msg_error32 <- "Le style de la palette doit etre de type caractere ('defaut', 'Insee_Rouge', 'Insee_Jaune', 'Insee_Bleu', 'Insee_Turquoise', 'Insee_Vert', 'Insee_Violet' ou 'Insee_Gris') / "
     if(!is.null(palettePos)) if(any(class(palettePos)!="character")) msg_error33 <- "La palette des classes doit etre un vecteur de type caractere / "
     if(!is.null(paletteNeg)) if(any(class(paletteNeg)!="character")) msg_error34 <- "La palette des classes doit etre un vecteur de type caractere / "
     if(any(class(colBorder)!="character")) msg_error35 <- "La couleur de la bordure doit etre de type caractere (nommee ou hexadecimal) / "
@@ -133,20 +133,6 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
                         "974"="2975",# UTM 40 S
                         "976"="4471")# UTM 38 S
 
-    if(is.null(palettePos) & is.null(paletteNeg))
-    {
-      palette <- recup_palette(stylePalette)
-      inseePos <- palette[[1]]
-      inseeNeg <- palette[[2]]
-    }else
-    {
-      inseePos <- NULL
-      inseeNeg <- NULL
-      stylePalette <- NULL
-      if(!is.null(palettePos)) inseePos <- palettePos
-      if(!is.null(paletteNeg)) inseeNeg <- paletteNeg
-    }
-
     # ANALYSE EN RONDS
 
     # Calcul du rayon du rond max
@@ -257,7 +243,7 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
     fond_leg_pr <- st_sf(geometry=st_sfc(st_geometry(fond_leg_pr),crs=st_crs(fondMaille)))
     fond_leg_ronds <- rbind(fond_leg_gr,fond_leg_pr)
 
-    fond_leg_ronds <- st_sf(VAR=c(max_var,max_var/3),geometry=st_sfc(st_geometry(fond_leg_ronds),crs=st_crs(fondMaille)))
+    fond_leg_ronds <- st_sf(ETI_VAL=c(max_var,max_var/3),geometry=st_sfc(st_geometry(fond_leg_ronds),crs=st_crs(fondMaille)))
     names(fond_leg_ronds) <- c(varVolume,"geometry")
 
     xmin <- min(st_coordinates(fond_leg_ronds)[,1]) - x_large
@@ -298,6 +284,7 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
       {
         carac_bornes <- calcul_bornes(as.data.frame(analyse_classes),bornes_analyse,varRatio,nbClasses,methode,stylePalette=stylePalette,palettePos=palettePos,paletteNeg=paletteNeg)
       }
+      
       bornes <- carac_bornes[[1]]
       bornes[1] <- max(as.numeric(as.data.frame(analyse_classes)[,varRatio]), na.rm = TRUE)
       bornes_sansext <- bornes[-1]
@@ -305,38 +292,80 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
       bornes_sansext <- sort(bornes_sansext, decreasing = TRUE)
       bornes <- c(max,bornes_sansext,min)
       bornes <- round(bornes,precisionLegClasses)
-
       pal_classes <- carac_bornes[[2]]
-    }else
+      
+    }else # methode manuel, bornes non NULL
     {
-      bornes_sansext <- sort(bornes, decreasing = TRUE)
-      bornes <- unique(c(max,bornes_sansext,min))
+      bornes <- sort(unique(c(max,bornes,min)))
+      if(min(bornes) != min) bornes <- bornes[which(bornes == min):length(bornes)]
+      if(max(bornes) != max) bornes <- bornes[1:which(bornes == max)]
       bornes <- round(bornes,precisionLegClasses)
-
-      if(min<0 & max>=0) # Si - et +
+      
+      if(min < 0 & max >= 0) # Si - et +
       {
-        pal_classes_pos <- inseePos[(length(inseePos)-length(bornes[bornes>0])+1):length(inseePos)]
-        pal_classes_neg <- inseeNeg[1:length(bornes[bornes<0])]
-        pal_classes <- c(pal_classes_pos,pal_classes_neg)
-      }
-      if(min>=0) # Si +
-      {
-        if(length(bornes)>=(length(inseePos)+1))
+        if(!is.null(stylePalette))
         {
-          pal_classes <- inseePos
+          if(!0 %in% bornes)
+          {
+            col_classe_zero <- recup_palette(stylePalette = "Insee_Gris", nbPos = 6)[[1]][1]
+            nb_pal_neg <- length(bornes[bornes < 0]) - 1
+            nb_pal_pos <- length(bornes[bornes > 0]) - 1
+            pal_classes <- recup_palette(stylePalette = stylePalette, nbNeg = nb_pal_neg, nbPos = nb_pal_pos)[[1]]
+            pal_classes <- c(pal_classes[0:nb_pal_neg], col_classe_zero, pal_classes[(nb_pal_neg + 1):(length(pal_classes) + 1)])
+            pal_classes <- pal_classes[!is.na(pal_classes)]
+          }else
+          {
+            nb_pal_neg <- length(bornes[bornes < 0])
+            nb_pal_pos <- length(bornes[bornes > 0])
+            pal_classes <- recup_palette(stylePalette = stylePalette, nbNeg = nb_pal_neg, nbPos = nb_pal_pos)[[1]] 
+          }
         }else
         {
-          pal_classes <- inseePos[-c(1:(length(inseePos)-length(bornes)+1))] # On enleve les couleurs fonces inutiles
+          palettePos <- palettePos[(length(palettePos)-length(bornes[bornes>0])+1):length(palettePos)]
+          paletteNeg <- paletteNeg[1:length(bornes[bornes<0])]
+          pal_classes <- c(paletteNeg,palettePos)
         }
       }
-      if(max<0) # Si -
+      if(min >= 0) # Si +
       {
-        if(length(bornes)>=(length(inseeNeg)+1))
+        if(!is.null(stylePalette))
         {
-          pal_classes <- inseeNeg
+          if(!0 %in% bornes)
+          {
+            nb_pal_pos <- length(bornes[bornes > 0]) - 1
+          }else
+          {
+            nb_pal_pos <- length(bornes[bornes > 0])
+          }
+          if(nb_pal_pos > 6) nb_pal_pos <- 6
+          nb_pal_neg <- 0
+          pal_classes <- recup_palette(stylePalette = stylePalette, nbPos = nb_pal_pos)[[1]]
         }else
         {
-          pal_classes <- inseeNeg[c(1:(length(bornes)-1))] # On enleve les couleurs fonces inutiles
+          palettePos <- palettePos[(length(palettePos)-length(bornes[bornes>0])+1):length(palettePos)]
+          paletteNeg <- paletteNeg[1:length(bornes[bornes<0])]
+          pal_classes <- c(paletteNeg,palettePos)
+        }
+      }
+      if(max <= 0) # Si -
+      {
+        if(!is.null(stylePalette))
+        {
+          if(!0 %in% bornes)
+          {
+            nb_pal_neg <- length(bornes[bornes < 0]) - 1
+          }else
+          {
+            nb_pal_neg <- length(bornes[bornes < 0])
+          }
+          if(nb_pal_neg > 6) nb_pal_neg <- 6
+          nb_pal_pos <- 0
+          pal_classes <- recup_palette(stylePalette = stylePalette, nbNeg = nb_pal_neg)[[1]]
+        }else
+        {
+          palettePos <- palettePos[(length(palettePos)-length(bornes[bornes>0])+1):length(palettePos)]
+          paletteNeg <- paletteNeg[1:length(bornes[bornes<0])]
+          pal_classes <- c(paletteNeg,palettePos)
         }
       }
     }
@@ -344,11 +373,10 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
     if(is.null(pal_classes)) pal_classes <- "grey"
 
     pal_classes[is.na(pal_classes)] <- "grey"
-    palette<-colorBin(palette=rev(pal_classes), domain=0:100, bins=bornes, na.color="grey")
+    palette<-colorBin(palette=pal_classes, domain=0:100, bins=bornes, na.color="grey")
     col <- palette(as.data.frame(analyse_classes)[,varRatio])
 
     analyse_classes <- cbind(as.data.frame(analyse_classes)[,-ncol(analyse_classes)],PALETTE=col,geometry=analyse_classes$geometry)
-
     ff <- lapply(1:length(pal_classes), function(x) analyse_classes[analyse_classes$PALETTE %in% rev(pal_classes)[x],"classe"] <<- x)
     rm(ff)
     analyse_classes <- analyse_classes[,c(1:(ncol(analyse_classes)-2),ncol(analyse_classes),ncol(analyse_classes)-1)]
@@ -371,6 +399,8 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
     }
 
     label_rectangle <- NULL
+    bornes <- sort(bornes, decreasing = TRUE)
+    
     if(is.null(labels))
     {
       label_rectangle <- NULL
@@ -434,26 +464,14 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
     }
 
     plot(st_geometry(fondMaille),col="transparent",border=colBorder,add=T)
-
+    
     for(i in 1:(length(bornes)-1))
     {
-      if(i == 1)
-      {
-        suppressWarnings(plot(fond_classes[as.data.frame(fond_classes)[,varRatio] <= bornes[1] &
-                                             as.data.frame(fond_classes)[,varRatio] >= bornes[2],],
-                              add=T,
-                              col=pal_classes[i],
-                              border=colBorder,
-                              lwd=1))
-      }else
-      {
-        suppressWarnings(plot(fond_classes[as.data.frame(fond_classes)[,varRatio] < bornes[i] &
-                                             as.data.frame(fond_classes)[,varRatio] >= bornes[i+1],],
-                              add=T,
-                              col=pal_classes[i],
-                              border=colBorder,
-                              lwd=1))
-      }
+      suppressWarnings(plot(fond_classes[as.data.frame(fond_classes)[,"classe"] == i,],
+                            add=T,
+                            col=rev(pal_classes)[i],
+                            border=colBorder,
+                            lwd=1))
     }
 
     plot(st_geometry(fond_ronds),border=colBorderRonds,add=T)
@@ -480,7 +498,7 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
 
     if(cadreLeg) suppressWarnings(plot(bbox_leg_ronds,add=T,col="white",border="white",lwd=1))
 
-    plot(st_geometry(fond_leg_ronds),add=T,col="transparent",border=colBorderRonds)
+    plot(st_geometry(fond_leg_ronds),add=T,col="transparent",border="black")
     text(pts2_grand_pl[1]+1000,pts2_grand_pl[2],labels=round(max_var,precisionLegRonds),cex=0.9,adj=0)
     text(pts2_petit_pl[1]+1000,pts2_petit_pl[2],labels=round(max_var/3,precisionLegRonds),cex=0.9,adj=0)
 
@@ -490,7 +508,7 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
 
     for(i in 1:length(pal_classes))
     {
-      suppressWarnings(plot(st_geometry(fond_leg_classes[i,]),add=T,col=pal_classes[i],border="black",lwd=1))
+      suppressWarnings(plot(st_geometry(fond_leg_classes[i,]),add=T,col=rev(pal_classes)[i],border="black",lwd=1))
       text(max(st_coordinates(fond_leg_classes[i,])[,1])+y_large/2,mean(st_coordinates(fond_leg_classes[i,])[,2]),labels=label_rectangle[i],cex=0.9,adj=0)
     }
 
